@@ -1,6 +1,7 @@
 use clap::{AppSettings, Subcommand};
 use std::error::Error;
 
+pub mod check_updates;
 pub mod find;
 pub mod init;
 
@@ -11,6 +12,7 @@ pub enum CtrlgCommand {
     Find(find::Cmd),
     #[clap(subcommand)]
     Init(init::Cmd),
+    CheckUpdates(check_updates::Cmd),
 }
 
 impl CtrlgCommand {
@@ -28,6 +30,11 @@ impl CtrlgCommand {
                 println!("{}", script);
                 Ok(())
             }
+            CtrlgCommand::CheckUpdates(cmd) => {
+                let instructions = cmd.run()?;
+                println!("{}", instructions);
+                Ok(())
+            }
         }
     }
 }
